@@ -10,19 +10,19 @@ import (
 	"strings"
 
 	"github.com/cppforlife/go-cli-ui/ui"
-	ctlapp "github.com/k14s/kapp/pkg/kapp/app"
-	ctlcap "github.com/k14s/kapp/pkg/kapp/clusterapply"
-	cmdcore "github.com/k14s/kapp/pkg/kapp/cmd/core"
-	cmdtools "github.com/k14s/kapp/pkg/kapp/cmd/tools"
-	ctlconf "github.com/k14s/kapp/pkg/kapp/config"
-	ctldiff "github.com/k14s/kapp/pkg/kapp/diff"
-	ctldgraph "github.com/k14s/kapp/pkg/kapp/diffgraph"
-	ctldiffui "github.com/k14s/kapp/pkg/kapp/diffui"
-	"github.com/k14s/kapp/pkg/kapp/logger"
-	ctllogs "github.com/k14s/kapp/pkg/kapp/logs"
-	ctlres "github.com/k14s/kapp/pkg/kapp/resources"
-	ctlresm "github.com/k14s/kapp/pkg/kapp/resourcesmisc"
 	"github.com/spf13/cobra"
+	ctlapp "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/app"
+	ctlcap "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/clusterapply"
+	cmdcore "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/core"
+	cmdtools "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/tools"
+	ctlconf "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/config"
+	ctldiff "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/diff"
+	ctldgraph "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/diffgraph"
+	ctldiffui "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/diffui"
+	"github.com/vmware-tanzu/carvel-kapp/pkg/kapp/logger"
+	ctllogs "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/logs"
+	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlresm "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resourcesmisc"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -152,8 +152,13 @@ func (o *DeployOptions) Run() error {
 		return err
 	}
 
+	meta, err := app.Meta()
+	if err != nil {
+		return err
+	}
+
 	existingResources, existingPodRs, err := o.existingResources(
-		newResources, labeledResources, resourceFilter, supportObjs.Apps, usedGKs)
+		newResources, labeledResources, resourceFilter, supportObjs.Apps, usedGKs, append(meta.LastChange.Namespaces, nsNames...))
 	if err != nil {
 		return err
 	}
@@ -178,6 +183,8 @@ func (o *DeployOptions) Run() error {
 	}
 
 	if o.DiffFlags.Run || hasNoChanges {
+		o.writeAppMetadataToFile(app)
+
 		if o.DiffFlags.Run && o.DiffFlags.ExitStatus {
 			return DeployDiffExitStatus{hasNoChanges}
 		}
@@ -202,7 +209,7 @@ func (o *DeployOptions) Run() error {
 	if o.DeployFlags.Logs {
 		cancelLogsCh := make(chan struct{})
 		defer func() { close(cancelLogsCh) }()
-		go o.showLogs(supportObjs.CoreClient, supportObjs.IdentifiedResources, existingPodRs, labelSelector, cancelLogsCh)
+		go o.showLogs(supportObjs.CoreClient, supportObjs.IdentifiedResources, existingPodRs, labelSelector, cancelLogsCh, append(meta.LastChange.Namespaces, nsNames...))
 	}
 
 	defer func() {
@@ -220,18 +227,7 @@ func (o *DeployOptions) Run() error {
 	}
 
 	err = touch.Do(func() error {
-		defer func() {
-			if o.DeployFlags.AppMetadataFile != "" {
-				meta, err := app.Meta()
-				if err != nil {
-					return
-				}
-				err = os.WriteFile(o.DeployFlags.AppMetadataFile, []byte(meta.AsString()), os.ModePerm)
-				if err != nil {
-					return
-				}
-			}
-		}()
+		defer o.writeAppMetadataToFile(app)
 
 		err := clusterChangeSet.Apply(clusterChangesGraph)
 		if err != nil {
@@ -356,7 +352,7 @@ func (o *DeployOptions) newResourcesFromFiles() ([]ctlres.Resource, error) {
 
 func (o *DeployOptions) existingResources(newResources []ctlres.Resource,
 	labeledResources *ctlres.LabeledResources, resourceFilter ctlres.ResourceFilter,
-	apps ctlapp.Apps, usedGKs []schema.GroupKind) ([]ctlres.Resource, []ctlres.Resource, error) {
+	apps ctlapp.Apps, usedGKs []schema.GroupKind, resourceNamespaces []string) ([]ctlres.Resource, []ctlres.Resource, error) {
 
 	labelErrorResolutionFunc := func(key string, val string) string {
 		items, _ := apps.List(nil)
@@ -380,7 +376,8 @@ func (o *DeployOptions) existingResources(newResources []ctlres.Resource,
 
 		//Scope resource searching to UsedGKs
 		IdentifiedResourcesListOpts: ctlres.IdentifiedResourcesListOpts{
-			GKsScope: usedGKs,
+			GKsScope:           usedGKs,
+			ResourceNamespaces: resourceNamespaces,
 		},
 	}
 
@@ -472,6 +469,17 @@ func (o *DeployOptions) existingPodResources(existingResources []ctlres.Resource
 	return existingPods
 }
 
+func (o *DeployOptions) writeAppMetadataToFile(app ctlapp.App) error {
+	if o.DeployFlags.AppMetadataFile != "" {
+		meta, err := app.Meta()
+		if err != nil {
+			return err
+		}
+		return os.WriteFile(o.DeployFlags.AppMetadataFile, []byte(meta.AsString()), os.ModePerm)
+	}
+	return nil
+}
+
 const (
 	deployLogsAnnKey              = "kapp.k14s.io/deploy-logs" // valid value is '' (default), for-new, for-existing, for-new-or-existing
 	deployLogsAnnDefault          = ""                         // equivalent to for-new
@@ -484,7 +492,7 @@ const (
 
 func (o *DeployOptions) showLogs(
 	coreClient kubernetes.Interface, identifiedResources ctlres.IdentifiedResources,
-	existingPodRs []ctlres.Resource, labelSelector labels.Selector, cancelCh chan struct{}) {
+	existingPodRs []ctlres.Resource, labelSelector labels.Selector, cancelCh chan struct{}, resourceNamespaces []string) {
 
 	existingPodsByUID := map[string]struct{}{}
 
@@ -518,7 +526,7 @@ func (o *DeployOptions) showLogs(
 
 	podWatcher := ctlres.FilteringPodWatcher{
 		podMatcherFunc,
-		identifiedResources.PodResources(labelSelector),
+		identifiedResources.PodResources(labelSelector, resourceNamespaces),
 	}
 
 	contFilterFunc := func(pod corev1.Pod) []string {
