@@ -4,7 +4,7 @@
 package config
 
 import (
-	ctlres "github.com/k14s/kapp/pkg/kapp/resources"
+	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
 )
 
 const defaultConfigYAML = `---
@@ -78,6 +78,7 @@ rebaseRules:
 - paths:
   - [metadata, annotations, pv.kubernetes.io/bind-completed]
   - [metadata, annotations, pv.kubernetes.io/bound-by-controller]
+  - [metadata, annotations, pv.kubernetes.io/migrated-to]
   - [metadata, annotations, volume.beta.kubernetes.io/storage-provisioner]
   - [spec, storageClassName]
   - [spec, volumeMode]
@@ -584,6 +585,17 @@ changeRuleBindings:
       - notMatcher:
           matcher: *disableDefaultChangeGroupAnnMatcher
 
+# Delete namespaces after deleting namespaced SAs so that resources like 
+# kapp-controller PackageInstalls can be deleted gracefully.
+- rules:  
+  - "delete before deleting change-groups.kapp.k14s.io/namespaces-{namespace}"
+  ignoreIfCyclical: true
+  resourceMatchers:
+  - andMatcher: 
+      matchers:
+      - notMatcher: {matcher: *disableDefaultChangeGroupAnnMatcher}
+      - anyMatcher: {matchers: *serviceAccountMatchers}
+
 # Insert roles/ClusterRoles before inserting any roleBinding/ClusterRoleBinding
 # Sometimes Binding Creation fail as corresponding Role is not created.
 # https://github.com/vmware-tanzu/carvel-kapp/issues/145
